import openai

from app.utils.print import print_error

MODEL_NAME = "gpt-3.5-turbo"

class Bot:
    def __init__(self, key):
        openai.api_key = key

    def request(self, chat):
        try:
            response = openai.ChatCompletion.create(
                model=MODEL_NAME,
                messages=chat
            )

            return response.choices[0].message.content

        except openai.error.APIError as e:
            print_error(e)

        except openai.error.Timeout as e:
            print_error(e)

        except openai.error.RateLimitError as e:
            print_error(e)

        except openai.error.APIConnectionError as e:
            print_error(e)

        except openai.error.InvalidRequestError as e:
            print_error(e)

        except openai.error.AuthenticationError as e:
            print_error(e)

            


from app.models.bot import Bot
from app.utils.print import print_message

class Chat:
    def __init__(self, key):
        self.bot = Bot(key)
        self.chat = []

    def log_message(self, role, content):
        message = {
            "role": role,
            "content": content
        }

        self.chat.append(message)

        if role != "user":
            print_message(message)


    def send_message(self, prompt):
        self.log_message("user", prompt)

        reply = self.bot.request(self.chat)

        if reply:
            self.log_message("assistant", reply)
            return reply




from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

with open("requirements.txt", "r", encoding="utf-8") as fh:
    requirements = fh.read()

setup(
    name = "jarvis-chat",
    version = "0.1.0",
    author = "Yohan Jhaveri",
    author_email = "yohanjhaveri@gmail.com",
    license = "MIT",
    description = "A simple CLI tool for interacting with ChatGPT",
    long_description = long_description,
    long_description_content_type = "text/markdown",
    url = "https://github.com/yohanjhaveri/jarvis",
    py_modules = ["jarvis", "app"],
    packages = find_packages(),
    install_requires = [requirements],
    python_requires=">=3.7",
    classifiers=[
        "Programming Language :: Python :: 3.8",
        "Operating System :: OS Independent",
    ],
    entry_points = """""""""
        [console_scripts]
        jarvis=jarvis:main
    """
)